@@ -8,12 +8,10 @@ class NewMetricEvent(IMessage):
     message_type = "new_metric"
     destination = "__dispatcher__"
     metric: BaseMetric
-    action: str
 
-    def __init__(self, metric: BaseMetric, action: str = "inc"):
+    def __init__(self, metric: BaseMetric):
         super().__init__()
         self.metric = metric
-        self.action = action
 
     def __str__(self):
         return f"NewMetricEvent({self.metric.__str__()})"
