@@ -4,6 +4,7 @@ import loguru
 
 from web_foundation import settings
 from web_foundation.app.events.metrics import NewMetricEvent, MetricRequest, MetricResponse
+from web_foundation.app.infrastructure.metrics.basemetric import CounterBaseMetric
 from web_foundation.app.infrastructure.metrics.exporter import BaseMetric
 from web_foundation.kernel import GenericIMessage
 from web_foundation.kernel.dispatcher import IDispatcher
@@ -49,31 +50,28 @@ class MetricsDispatcher(IDispatcher):
             self.collected_metrics.update({event.metric.name: {event.metric.labels_concat: event.metric}})
         else:
             if metr.get(event.metric.labels_concat):
-                if event.action == "inc":
-                    metr[event.metric.labels_concat].value += event.metric.value
+                # loguru.logger.warning(f"get {event.metric}")
+                metr[event.metric.labels_concat] += event.metric
             else:
+                # loguru.logger.warning(f"set {event.metric}")
                 metr[event.metric.labels_concat] = event.metric
-        #
-        # loguru.logger.warning(event.metric)
-        # if isinstance(event.metric, BaseMetric):
-        #     self.collected_metrics.update({event.metric.name: event.metric})
 
     async def track_event(self, msg: GenericIMessage):
         await super(MetricsDispatcher, self).track_event(msg)
         if settings.EVENTS_METRIC_ENABLE:
-            event_counter = BaseMetric("events_counter", self._msg_global_index)
+            event_counter = CounterBaseMetric("events_counter", self._msg_global_index)
             self.collected_metrics.update({"events_counter": {"dispatcher_events_counter": event_counter}})
 
             named_event_counter = self.collected_metrics.get("named_events_counter")
             if not named_event_counter:
-                mtr = BaseMetric("named_events_counter", value=1)
+                mtr = CounterBaseMetric("named_events_counter", value=1)
                 mtr.add_label(event_name=msg.message_type)
                 named_event_counter = {msg.message_type: mtr}
                 self.collected_metrics["named_events_counter"] = named_event_counter
             elif named_event_counter.get(msg.message_type):
-                named_event_counter[msg.message_type].value += 1
+                named_event_counter[msg.message_type].inc()
             else:
-                mtr = BaseMetric("named_events_counter", value=1)
+                mtr = CounterBaseMetric("named_events_counter", value=1)
                 mtr.add_label(event_name=msg.message_type)
                 named_event_counter[msg.message_type] = mtr
             if settings.DEBUG:
