@@ -19,12 +19,14 @@ class JsonExporter(MetricExporter):
     def export(cls, metrics: List[BaseMetric]) -> Dict[str, TypeJSON]:
         dic = {}
         for metric in metrics:
+            if not metric:
+                continue
             if not dic.get(metric.name):
-                dic[metric.name] = [{"value": metric.value,
+                dic[metric.name] = [{"value": metric.collect(),
                                      "labels": metric.labels,
                                      "timestamp": metric.timestamp}]
             else:
-                dic[metric.name].append({"value": metric.value,
+                dic[metric.name].append({"value": metric.collect(),
                                          "labels": metric.labels,
                                          "timestamp": metric.timestamp})
         return dic
