@@ -8,10 +8,11 @@ from sanic.response import BaseHTTPResponse
 
 from web_foundation import settings
 from web_foundation.app.events.metrics import NewMetricEvent
+from web_foundation.app.infrastructure.metrics.basemetric import CounterBaseMetric, HistogramBaseMetric, \
+    SummaryBaseMetric
 from web_foundation.app.infrastructure.metrics.exporter import BaseMetric
 from web_foundation.kernel import IChannel
 
-# if settings.METRICS_ENABLE:
 try:
     from prometheus_client.metrics import Gauge, Histogram, Counter, MetricWrapperBase
 except ImportError:
@@ -25,8 +26,8 @@ class MetricsMixin:
     def _reg_metrics(self):
         pass
 
-    async def give_metric(self, metric: BaseMetric, action: str = "inc"):
-        asyncio.create_task(self._channel.produce(NewMetricEvent(metric, action)))
+    async def give_metric(self, metric: BaseMetric):
+        asyncio.create_task(self._channel.produce(NewMetricEvent(metric)))
 
 
 class ApiMetricsMixin(MetricsMixin):
@@ -47,19 +48,23 @@ class ApiMetricsMixin(MetricsMixin):
             if not settings.METRICS_ENABLE:
                 return
             else:
-                metr = BaseMetric(f"exec_request_time")
-                metr.value = time.time() - request.app.ctx.metrics.exec_time
-                metr.add_label(worker=self._name,
-                               request=request.path,
+                metr = HistogramBaseMetric(f"exec_request_time")
+                metr.observe(time.time() - request.app.ctx.metrics.exec_time)
+                metr.add_label(request=request.path,
                                method=request.method,
                                status=str(response.status))
                 await self.give_metric(metr)
-                metr = BaseMetric(f"request_path_count", value=1)
-                metr.add_label(worker=self._name,
-                               request=request.path,
+                metr = CounterBaseMetric(f"request_path_count", value=1)
+                metr.add_label(request=request.path,
                                method=request.method,
                                status=str(response.status))
-                asyncio.create_task(self.give_metric(metr))
+                await self.give_metric(metr)
+                metr = SummaryBaseMetric(f"request_path_latency")
+                metr.add_label(request=request.path,
+                               method=request.method,
+                               status=str(response.status))
+                metr.observe(time.time() - request.app.ctx.metrics.exec_time)
+                await self.give_metric(metr)
 
         self.sanic_app.register_middleware(metrics_before)
         self.sanic_app.register_middleware(metrics_after, "response")
