@@ -7,6 +7,7 @@ from sanic.handlers import ErrorHandler
 from sanic.exceptions import SanicException
 
 from web_foundation.app.errors.application.application import ApplicationError
+from web_foundation import settings
 
 
 class StatusCodes:
@@ -91,7 +92,7 @@ class ExtendedErrorHandler(ErrorHandler):
         return exception_response(
             request,
             exception,
-            debug=self.debug,
+            debug=settings.DEBUG,
             base=self.base,
             fallback=fallback,
             renderer=renderer
